fix_int16_images — MSUMastro toolbox 0.1 documentation

# fix_int16_images

`msumastro.header_processing.patchers.` `fix_int16_images`(directory=None, new_file_ext=None)

  Repair unsigned int16 images saved as signed int16.

  Use with care; if your data really is signed int16 this will corrupt it.

  Parameters: | dir : str, optional Directory containing the files to be patched. Default is the current directory, `.` new_file_ext : str, optional Name added to the FITS files with updated header information. It is added to the base name of the input file, between the old file name and the .fit or .fits extension.